Crate uv_auth

Crate uv_auth 

Structs

AuthMiddleware
A middleware that adds basic authentication to requests.
CredentialsCache
Index
Indexes
KeyringProvider
A backend for retrieving credentials from a keyring.
Realm
Used to determine if authentication information should be retained on a new URL. Based on the specification defined in RFC 7235 and 7230.
RealmRef
A reference to a Realm that can be used for zero-allocation comparisons.
Service
A service URL that wraps DisplaySafeUrl for CLI usage.
TextCredentialStore
A credential store with a plain text storage backend.
Username

Enums

AuthBackend
The storage backend to use in uv auth commands.
AuthPolicy
When to use authentication.
Credentials
CredentialsFromUrlError
TomlCredentialError
Errors that can occur when working with TOML credential storage.