Structs
- Auth
Middleware - A middleware that adds basic authentication to requests.
- Credentials
Cache - Index
- Indexes
- Keyring
Provider - A backend for retrieving credentials from a keyring.
- Realm
- Used to determine if authentication information should be retained on a new URL. Based on the specification defined in RFC 7235 and 7230.
- Realm
Ref - A reference to a
Realmthat can be used for zero-allocation comparisons. - Service
- A service URL that wraps
DisplaySafeUrlfor CLI usage. - Text
Credential Store - A credential store with a plain text storage backend.
- Username
Enums
- Auth
Backend - The storage backend to use in
uv authcommands. - Auth
Policy - When to use authentication.
- Credentials
- Credentials
From UrlError - Toml
Credential Error - Errors that can occur when working with TOML credential storage.